@@ -94,12 +94,7 @@ class Modal(hg.DIV):
         """
         buttons = (Button(_("Cancel"), buttontype="ghost", data_modal_close=True),)
         if submitlabel:
-            buttons += (
-                Button(
-                    submitlabel,
-                    type="submit",
-                ),
-            )
+            buttons += (Button(submitlabel, type="submit", form=""),)
 
         modal = cls(
             heading,
@@ -113,6 +108,7 @@ class Modal(hg.DIV):
         if submitlabel:
             buttons[1].attributes["hx_post"] = url
             buttons[1].attributes["hx_target"] = f"#{modal.id} .bx--modal-content"
+            buttons[1].attributes["hx_include"] = f"#{modal.id} .bx--modal-content"
 
         modal.openerattributes["hx_get"] = url
         modal.openerattributes["hx_target"] = f"#{modal.id} .bx--modal-content"
