@@ -56,27 +56,6 @@ def try_call(var, *args, **kwargs):
     return var(*args, **kwargs) if callable(var) else var
 
 
-class Action:
-    """Represents a user-clickable action
-    js, label, icon and permissions can be str, lazy string or a callable function.
-    The function takes the current request as the only argument.
-    """
-
-    def __init__(self, js, label="", iconname=None, permissions=[]):
-        self.js = js
-        self.label = label
-        self.iconname = iconname
-        self._permissions = permissions
-
-    def has_permission(self, request, obj=None):
-        return all(
-            [
-                request.user.has_perm(perm, obj) or request.user.has_perm(perm)
-                for perm in try_call(self._permissions, request)
-            ]
-        )
-
-
 class Item:
     def __init__(self, link, group, order=None):
         if not isinstance(link, Link):
