@@ -2,9 +2,13 @@
 // support onload after page loaded for all elements
 document.addEventListener(
     "DOMContentLoaded",
-    (e) => { $$('[onload]:not(body):not(frame):not(iframe):not(img):not(link):not(script):not(style)')._.fire("load"); initAllChoices()}
+    () => bread_load_elements()
 );
 
+function bread_load_elements() {
+    $$('[onload]:not(body):not(frame):not(iframe):not(img):not(link):not(script):not(style)')._.fire("load")
+}
+
 function updateMultiselect(e) {
     let elem = $('.bx--list-box__selection', e);
     if (elem) {
@@ -32,19 +36,6 @@ function clearMultiselect(e) {
     updateMultiselect(e);
 }
 
-function initAllChoices(element=$("body")) {
-    // this initializes the old choices widget from ChoicesJS which do no longer really use
-    // Remove this in the next JS refactoring
-    return;
-    for(let e of $$("fieldset[disabled] select[multiple]", element)) {
-        makeChoices(e).disable();
-    }
-
-    for(let e of $$(":not(fieldset[disabled]) select[multiple]", element)) {
-        makeChoices(e);
-    }
-}
-
 function makeChoices(selectElem) {
     // prevent initialization in template forms for django formsets
     if(selectElem.closest(".template-form")) {
@@ -129,7 +120,7 @@ function formset_add(form_prefix, list_container) {
     update_add_button(form_prefix);
     updateMultiselect(container_elem);
 
-    $$('[onload]:not(body):not(frame):not(iframe):not(img):not(link):not(script):not(style)', container_elem)._.fire("load");
+    bread_load_elements();
     htmx.process(container_elem);
 }
 
@@ -175,3 +166,16 @@ function submitbulkaction(table, actionurl, method="GET") {
     document.body.appendChild(form);
     form.submit();
 }
+
+// helper functions to set and get bread-namespaced cookies
+function setBreadCookie(key, value) {
+    document.cookie = "bread-" + key + "=" + encodeURIComponent(value) + "; path=/";
+}
+
+function getBreadCookie(key, _default=null) {
+    var ret = document.cookie.split('; ').find(row => row.startsWith("bread-" + key + '='))
+    if(!ret)
+        return _default;
+    ret = ret.split('=')[1];
+    return ret ? decodeURIComponent(ret) : _default;
+}
